[ARVADOS] updated: 1.3.0-944-g35faa53ac

Git user git at public.curoverse.com
Thu May 23 18:47:50 UTC 2019


Summary of changes:
 build/run-library.sh | 11 +++++++----
 sdk/pam/setup.py     |  7 -------
 2 files changed, 7 insertions(+), 11 deletions(-)

       via  35faa53ac374d075e07d5d9fabe128f97391fa76 (commit)
      from  da266d025f557cdd392d750ef0ff4b58d3757251 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit 35faa53ac374d075e07d5d9fabe128f97391fa76
Author: Ward Vandewege <wvandewege at veritasgenetics.com>
Date:   Thu May 23 14:45:35 2019 -0400

    Make sure that the libpam-arvados package puts its various files in the place
    where the pam subsystem will expect them, not inside the virtualenv.
    
    Also, remove the code from sdk/pam/setup.py that installed a copy of the
    libpam-arvados.py file under /usr/data/lib/security/libpam_arvados.py for
    legacy reasons.
    
    refs #9945
    refs #15186
    
    Arvados-DCO-1.1-Signed-off-by: Ward Vandewege <wvandewege at veritasgenetics.com>

diff --git a/sdk/pam/setup.py b/sdk/pam/setup.py
index c94f5b41f..9bc2cef60 100755
--- a/sdk/pam/setup.py
+++ b/sdk/pam/setup.py
@@ -42,13 +42,6 @@ setup(name='arvados-pam',
           ('share/pam-configs', ['pam-configs/arvados']),
           ('share/doc/arvados-pam', ['LICENSE-2.0.txt', 'README.rst']),
           ('share/doc/arvados-pam/examples', glob.glob('examples/*')),
-
-          # The arvados build scripts used to install data files to
-          # "/usr/data/*" but now install them to "/usr/*". Here, we
-          # install an extra copy in the old location so existing pam
-          # configs can still work. When old systems have had a chance
-          # to update to the new paths, this line can be removed.
-          ('data/lib/security', ['lib/libpam_arvados.py']),
       ],
       install_requires=[
           'arvados-python-client>=0.1.20150801000000',

-----------------------------------------------------------------------


hooks/post-receive
diff --git a/build/run-library.sh b/build/run-library.sh
index 141c49e62..1aa3e3cfd 100755
--- a/build/run-library.sh
+++ b/build/run-library.sh
@@ -638,10 +638,13 @@ fpm_build_virtualenv () {
     done
   fi
 
-  # the libpam module should place this file in the historically correct place
-  # so as not to break backwards compatibility
-  if [[ -e "$WORKSPACE/$PKG_DIR/dist/build/usr/share/python2.7/dist/libpam-arvados/lib/security/libpam_arvados.py" ]]; then
-    COMMAND_ARR+=("usr/share/$python/dist/$PYTHON_PKG/data/lib/security/libpam_arvados.py=/usr/data/lib/security/")
+  # the libpam module should place a few files in the correct place for the pam
+  # subsystem
+  if [[ -e "$WORKSPACE/$PKG_DIR/dist/build/usr/share/$python/dist/$PYTHON_PKG/lib/security/libpam_arvados.py" ]]; then
+    COMMAND_ARR+=("usr/share/$python/dist/$PYTHON_PKG/lib/security/libpam_arvados.py=/usr/lib/security/")
+  fi
+  if [[ -e "$WORKSPACE/$PKG_DIR/dist/build/usr/share/$python/dist/$PYTHON_PKG/share/pam-configs/arvados" ]]; then
+    COMMAND_ARR+=("usr/share/$python/dist/$PYTHON_PKG/share/pam-configs/arvados=/usr/share/pam-configs/")
   fi
 
   # the python-arvados-cwl-runner package comes with cwltool, expose that version
-- 




More information about the arvados-commits mailing list